import numpy as np


def get_wfs(even_evecs, odd_evecs, majorana_operators, idx=0):
    """
    Computes the transition matrix element of the Majorana operators
    for all sites between the odd and even state with index `idx`.
    """
    operators = majorana_operators
    odd_gamma_even = []
    for gamma in operators:
        odd_gamma_even.append(
            np.abs(odd_evecs[:, idx].conj() @ gamma @ even_evecs[:, idx])**2
        )
    return np.array(odd_gamma_even)

def majorana_wfs(wf):
    rho1 = np.abs(wf[::2]**2 + wf[1::2]**2)
    rho2 = np.abs(wf[::2]**2 - wf[1::2]**2)
    return rho1, rho2


def polarization_from_wfs(ws, zs):
    """
    Calculate M for all sites based on w and z
    """
    num = (ws**2 - zs**2)
    num = num.reshape(3, 2)
    num = np.sum(num, axis=1)
    den = (ws**2 + zs**2)
    den = den.reshape(3, 2)
    den = np.sum(den, axis=1)
    return num/den